Hi !
====

You're using saruman and want to report a bug or problem or you want to fix something yourself?
Feel free! Github is the place to do so.

- Report bugs or problems at https://github.com/tychota/saruman/issues
- Or make a fork, fix the bug or add something and open a pull request.
- You can mail  `Tycho Tatitscheff <mailto://tycho.tatitscheff+saruman@gadz.org>`_ if you want to ask a question, too.
  Or if you want to tell us about an idea you have.

Normally you ought to get a reply within a few days, but often within a couple of hours.
If it takes longer, feel free to email us as a reminder.

If you want to work on saruman, read the developer info in doc/source/developing.rst.
Or read it online at http://saruman.readthedocs.org/en/latest/developing.html .
